Index: gfx/canvas_skia_paint.h |
=================================================================== |
--- gfx/canvas_skia_paint.h (revision 50452) |
+++ gfx/canvas_skia_paint.h (working copy) |
@@ -2,19 +2,19 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef GFX_CANVAS_PAINT_H_ |
-#define GFX_CANVAS_PAINT_H_ |
+#ifndef GFX_CANVAS_SKIA_PAINT_H_ |
+#define GFX_CANVAS_SKIA_PAINT_H_ |
#include "gfx/canvas.h" |
#include "skia/ext/canvas_paint.h" |
// Define a skia::CanvasPaint type that wraps our gfx::Canvas like the |
// skia::PlatformCanvasPaint wraps PlatformCanvas. |
namespace gfx { |
-typedef skia::CanvasPaintT<Canvas> CanvasPaint; |
+typedef skia::CanvasPaintT<CanvasSkia> CanvasSkiaPaint; |
} // namespace gfx |
-#endif // GFX_CANVAS_PAINT_H_ |
+#endif // GFX_CANVAS_SKIA_PAINT_H_ |
@@ -2,19 +2,19 @@ |
#include "gfx/canvas.h" |
#include "skia/ext/canvas_paint.h" |
-// Define a skia::CanvasPaint type that wraps our gfx::Canvas like the |
+// Define a gfx::CanvasSkiaPaint type that wraps our gfx::Canvas like the |
// skia::PlatformCanvasPaint wraps PlatformCanvas. |
namespace gfx { |